@@ -9,13 +9,13 @@ from importlib import metadata, resources
 import click
 import distro
 from progress.spinner import Spinner
+from hotsos.core import plugintools
 from hotsos.core.root_manager import DataRootManager
 from hotsos.core.config import HotSOSConfig
-from hotsos.core.log import setup_logging, log
+from hotsos.core.log import log, LoggingManager
 from hotsos.client import (
     HotSOSClient,
     OutputManager,
-    PLUGIN_CATALOG,
 )
 
 SNAP_ERROR_MSG = """ERROR: hotsos is installed as a snap which only supports
@@ -81,7 +81,7 @@ def get_repo_info():
 
 
 def set_plugin_options(f):
-    for plugin in PLUGIN_CATALOG:
+    for plugin in plugintools.PLUGINS:
         click.option('--{}'.format(plugin), default=False, is_flag=True,
                      help='Run the {} plugin.'.format(plugin))(f)
 
@@ -152,6 +152,14 @@ def progress_spinner(show_spinner, spinner_msg):
 
 def main():
     @click.command(name='hotsos')
+    @click.option('--event', default='',
+                  help=('Filter a particular event name. Useful for '
+                        'testing/debugging. Format is '
+                        '<plugin name>.<group>.<event>'))
+    @click.option('--scenario', default='',
+                  help=('Filter a particular scenario name. Useful for '
+                        'testing/debugging. Format is '
+                        '<plugin name>.<group>.<scenario>'))
     @click.option('--sos-unpack-dir', default=None,
                   help=('Location used to unpack sosreports. Useful if you '
                         'want to cache the unpacked sosreport for subsequent '
@@ -233,7 +241,7 @@ def main():
             quiet, save, output_format, html_escape, short, very_short,
             force, event_tally_granularity, max_logrotate_depth,
             max_parallel_tasks, list_plugins, machine_readable, output_path,
-            command_timeout, sos_unpack_dir, **kwargs):
+            command_timeout, sos_unpack_dir, scenario, event, **kwargs):
         """
         Run this tool on a host or against a sosreport to perform
         analysis of specific applications and the host itself. A summary of
@@ -257,86 +265,101 @@ def main():
             host.
         """  # noqa
 
-        minimal_mode = None
-        if short:
-            minimal_mode = 'short'
-        elif very_short:
-            minimal_mode = 'very-short'
-
-        HotSOSConfig.force_mode = force
-        repo_info = get_repo_info()
-        if repo_info:
-            HotSOSConfig.repo_info = repo_info
-
         _version = get_version()
-        HotSOSConfig.hotsos_version = _version
-        HotSOSConfig.command_timeout = command_timeout
-
         if version:
             print(_version)
             return
 
-        with DataRootManager(data_root, sos_unpack_dir=sos_unpack_dir) as drm:
-            if is_snap() and drm.data_root == '/':
-                print(SNAP_ERROR_MSG)
-                sys.exit(1)
+        config = {'repo_info': get_repo_info(),
+                  'force_mode': force,
+                  'hotsos_version': _version,
+                  'command_timeout': command_timeout,
+                  'use_all_logs': all_logs,
+                  'plugin_yaml_defs': defs_path,
+                  'templates_path': templates_path,
+                  'event_tally_granularity': event_tally_granularity,
+                  'max_logrotate_depth': max_logrotate_depth,
+                  'max_parallel_tasks': max_parallel_tasks,
+                  'machine_readable': machine_readable,
+                  'debug_mode': debug,
+                  'scenario_filter': scenario,
+                  'event_filter': event}
+        HotSOSConfig.set(**config)
 
-            HotSOSConfig.set(use_all_logs=all_logs, plugin_yaml_defs=defs_path,
-                             templates_path=templates_path,
-                             data_root=drm.data_root,
-                             event_tally_granularity=event_tally_granularity,
-                             max_logrotate_depth=max_logrotate_depth,
-                             max_parallel_tasks=max_parallel_tasks,
-                             machine_readable=machine_readable)
+        with LoggingManager() as logmanager:
+            with DataRootManager(data_root,
+                                 sos_unpack_dir=sos_unpack_dir) as drm:
+                HotSOSConfig.data_root = drm.data_root
+                if is_snap() and drm.data_root == '/':
+                    print(SNAP_ERROR_MSG)
+                    sys.exit(1)
 
-            if debug and quiet:
-                sys.stderr.write('ERROR: cannot use both --debug and '
-                                 '--quiet\n')
-                return
+                if debug and quiet:
+                    sys.stderr.write('ERROR: cannot use both --debug and '
+                                     '--quiet\n')
+                    return
 
-            HotSOSConfig.debug_mode = debug
+                # Set a name so that logs have this until real plugins are run.
+                log.name = 'hotsos.cli'
 
-            setup_logging()
-            # Set a name so that logs have this until real plugins are run.
-            log.name = 'hotsos.cli'
+                if list_plugins:
+                    sys.stdout.write('\n'.join(plugintools.PLUGINS.keys()))
+                    sys.stdout.write('\n')
+                    return
 
-            if list_plugins:
-                sys.stdout.write('\n'.join(PLUGIN_CATALOG.keys()))
-                sys.stdout.write('\n')
-                return
+                if quiet:
+                    show_spinner = False
+                    spinner_msg = ''
+                else:
+                    show_spinner = not debug
+                    if show_spinner:
+                        sys.stdout.write(
+                            'INFO: analysing {}\n'.format(drm.name))
+                    spinner_msg = 'INFO: analysing '
 
-            if quiet:
-                show_spinner = False
-                spinner_msg = ''
-            else:
-                show_spinner = not debug
-                spinner_msg = 'INFO: analysing {} '.format(drm.name)
+                with progress_spinner(show_spinner, spinner_msg):
+                    plugins = []
+                    for k, v in kwargs.items():
+                        if v is True:
+                            plugins.append(k)
 
-            with progress_spinner(show_spinner, spinner_msg):
-                plugins = []
-                for k, v in kwargs.items():
-                    if v is True:
-                        plugins.append(k)
+                    if plugins:
+                        # always run these
+                        plugins.append('hotsos')
+                        if 'system' not in plugins:
+                            plugins.append('system')
 
-                if plugins:
-                    # always run these
-                    plugins.append('hotsos')
-                    if 'system' not in plugins:
-                        plugins.append('system')
+                    client = HotSOSClient(plugins)
+                    try:
+                        client.run()
+                    except Exception as exc:
+                        log.exception("An exception occurred while running "
+                                      "plugins")
+                        print('\nException running plugins:', exc)
+                        print('See temp log file for possible details:',
+                              logmanager.temp_log_path)
+                        logmanager.delete_temp_file = False
+                        raise
 
-                client = HotSOSClient(plugins)
-                client.run()
-                summary = client.summary
+                    summary = client.summary
 
-            if save:
-                path = summary.save(drm.basename, html_escape=html_escape,
-                                    output_path=output_path)
-                sys.stdout.write("INFO: output saved to {}\n".format(path))
-            else:
-                out = summary.get(fmt=output_format, html_escape=html_escape,
-                                  minimal_mode=minimal_mode)
-                if out:
-                    sys.stdout.write("{}\n".format(out))
+                if save:
+                    path = summary.save(drm.basename, html_escape=html_escape,
+                                        output_path=output_path)
+                    sys.stdout.write("INFO: output saved to {}\n".format(path))
+                else:
+                    if short:
+                        minimal_mode = 'short'
+                    elif very_short:
+                        minimal_mode = 'very-short'
+                    else:
+                        minimal_mode = None
+
+                    out = summary.get(fmt=output_format,
+                                      html_escape=html_escape,
+                                      minimal_mode=minimal_mode)
+                    if out:
+                        sys.stdout.write("{}\n".format(out))
 
     cli(prog_name='hotsos')
 
