@@ -85,7 +85,8 @@ class HotSOSConfigOpts(ConfigOptGroupBase):
                            description='Version of hotsos being run.',
                            default_value=None, value_type=str))
         self.add(ConfigOpt(name='debug_mode',
-                           description='Set to True to enable debug logging',
+                           description='Set to True to enable debug logging '
+                                       'to standard output',
                            default_value=False, value_type=bool))
         self.add(ConfigOpt(name='plugin_yaml_defs',
                            description='Path to yaml-defined checks.',
@@ -109,6 +110,22 @@ class HotSOSConfigOpts(ConfigOptGroupBase):
                                         "by host_helpers.cli when executing "
                                         "binary commands"),
                            default_value=300, value_type=int))
+        self.add(ConfigOpt(name='event_filter',
+                           description=("Name of event to run. Set this if "
+                                        "you want to run a single event. "
+                                        "Useful for testing/debugging"),
+                           default_value='', value_type=str))
+        self.add(ConfigOpt(name='scenario_filter',
+                           description=("Name of scenario to run. Set this if "
+                                        "you want to run a single scenario. "
+                                        "Useful for testing/debugging"),
+                           default_value='', value_type=str))
+        self.add(ConfigOpt(name='debug_log_levels',
+                           description=("Debug mode log levels for "
+                                        "submodules/dependencies"),
+                           default_value={'propertree': 'WARNING',
+                                          'searchkit': 'DEBUG'},
+                           value_type=dict))
 
     @property
     def name(self):
