@@ -11,25 +11,29 @@ from .network import (  # noqa: F403,F401
     HostNetworkingHelper,
 )
 from .packaging import (  # noqa: F403,F401
-    DPKGVersionCompare,
+    DPKGVersion,
     APTPackageHelper,
     DockerImageHelper,
     SnapPackageHelper,
 )
-from .pebble import (  # noqa: F403,F401
+from .pebble import (  # noqa: F403,F401 pylint: disable=cyclic-import
     PebbleHelper,
 )
 from .ssl import (  # noqa: F403,F401
     SSLCertificate,
     SSLCertificatesHelper,
 )
-from .systemd import (  # noqa: F403,F401
+from .systemd import (  # noqa: F403,F401 pylint: disable=cyclic-import
     SystemdHelper,
 )
-from .uptime import (  # noqa: F403,F401
+from .uptime import (  # noqa: F403,F401 pylint: disable=cyclic-import
     UptimeHelper,
 )
 from .sysctl import (  # noqa: F403,F401
     SYSCtlFactory,
     SYSCtlConfHelper,
 )
+from .apparmor import (  # noqa: F403,F401
+    AAProfileFactory,
+    ApparmorHelper,
+)
