@@ -41,7 +41,7 @@ def catch_exceptions(*exc_types):
                 else:
                     log.debug(msg)
 
-                if type(exc) == json.JSONDecodeError:
+                if isinstance(exc, json.JSONDecodeError):
                     raise CLIExecError(return_value={}) from exc
 
                 raise CLIExecError(return_value=[]) from exc
@@ -52,7 +52,11 @@ def catch_exceptions(*exc_types):
 
 
 class SourceNotFound(Exception):
-    pass
+    def __init__(self, path):
+        self.path = path
+
+    def __repr__(self):
+        return "source path '{}' not found".format(self.path)
 
 
 class CommandNotFound(Exception):
@@ -239,7 +243,7 @@ class FileCmd(CmdBase):
             self.path = self.path.format(**kwargs)
 
         if not os.path.exists(self.path):
-            raise SourceNotFound()
+            raise SourceNotFound(self.path)
 
         if skip_load_contents:
             CmdOutput(None, self.path)
@@ -293,7 +297,7 @@ class BinFileCmd(FileCmd):
         # TODO: find a better way to handle this because path may still need
         # formatting.
         if not os.path.exists(self.original_path):
-            raise SourceNotFound()
+            raise SourceNotFound(self.original_path)
 
         if args:
             self.path = self.path.format(*args)
@@ -375,49 +379,107 @@ class JournalctlBinFileCmd(BinFileCmd, JournalctlBase):
             self.path = "{} --since {}".format(self.path, self.since_date)
 
 
-class OVSDPCTLFileCmd(FileCmd):
+class OVSAppCtlBinCmd(BinCmd):
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.register_hook("pre-exec", self.performat_sos_datapath)
+    def __call__(self, *args, **kwargs):
+        # Set defaults for optional args
+        for key in ['flags', 'args']:
+            if key not in kwargs:
+                kwargs[key] = ''
 
-    def performat_sos_datapath(self, **kwargs):
-        if 'datapath' in kwargs:
-            datapath = kwargs['datapath'].replace('@', '_')
-            self.path = self.path.format(datapath=datapath)
+        return super().__call__(*args, **kwargs)
 
 
-class OVSOFCTLBinCmd(BinCmd):
+class OVSAppCtlFileCmd(FileCmd):
+
+    def __call__(self, *args, **kwargs):
+        for key in ['flags', 'args']:
+            if key in kwargs:
+                kwargs[key] = '_{}'.format(kwargs[key])
+            else:
+                kwargs[key] = ''
+
+        if 'args' in kwargs and kwargs['command'].startswith('dpctl/'):
+            # e.g. this would be for dpctl datapath
+            kwargs['args'] = kwargs['args'].replace('@', '_')
+
+        kwargs['command'] = kwargs['command'].replace('/', '.')
+        try:
+            out = super().__call__(*args, **kwargs)
+        except SourceNotFound:
+            log.debug("%s: source not found: %s", self.__class__.__name__,
+                      self.path)
+            raise
+
+        return out
+
+
+class OVSOFCtlCmdBase(object):
     OFPROTOCOL_VERSIONS = ['OpenFlow15', 'OpenFlow14', 'OpenFlow13',
                            'OpenFlow12', 'OpenFlow11', 'OpenFlow10']
 
+
+class OVSOFCtlBinCmd(OVSOFCtlCmdBase, BinCmd):
+
     def __call__(self, *args, **kwargs):
         """
-        First try without specifying protocol version then is error is raised
-        try with version.
+        First try without specifying protocol version. If error is raised
+        try with different versions until we get a result.
         """
         self.cmd = "ovs-ofctl {}".format(self.cmd)
         try:
             return super().__call__(*args, **kwargs)
         except CLIExecError:
-            log.debug("ofctl command with no protocol version failed")
+            log.debug("%s: command with no protocol version failed",
+                      self.__class__.__name__)
 
         # If the command raised an exception it will have been caught by the
         # catch_exceptions decorator and [] returned. We have no way of knowing
         # if that was the actual return or an exception was raised so we just
         # go ahead and retry with specific OF versions until we get a result.
         for ver in self.OFPROTOCOL_VERSIONS:
-            log.debug("trying ofctl command with protocol version %s", ver)
+            log.debug("%s: trying again with protocol version %s",
+                      self.__class__.__name__, ver)
             self.reset()
             self.cmd = "ovs-ofctl -O {} {}".format(ver, self.cmd)
             try:
                 return super().__call__(*args, **kwargs)
             except CLIExecError:
-                log.debug("ofctl command with protocol version %s failed", ver)
+                log.debug("%s: command with protocol version %s failed",
+                          self.__class__.__name__, ver)
 
         return CmdOutput([])
 
 
+class OVSOFCtlFileCmd(OVSOFCtlCmdBase, FileCmd):
+
+    def __call__(self, *args, **kwargs):
+        """
+        We do this in reverse order to bin command since it won't actually
+        raise an error.
+        """
+        for ver in self.OFPROTOCOL_VERSIONS:
+            log.debug("%s: trying again with protocol version %s",
+                      self.__class__.__name__, ver)
+            self.reset()
+            try:
+                kwargs['ofversion'] = '_-O_{}'.format(ver)
+                out = super().__call__(*args, **kwargs)
+                if out.value and 'version negotiation failed' in out.value[0]:
+                    continue
+
+                return out
+            except SourceNotFound:
+                pass
+
+        try:
+            kwargs['ofversion'] = ''
+            return super().__call__(*args, **kwargs)
+        except SourceNotFound:
+            log.debug("%s: command with no protocol version failed",
+                      self.__class__.__name__)
+
+
 class DateBinCmd(BinCmd):
 
     def __init__(self, *args, **kwargs):
@@ -492,7 +554,7 @@ class CephJSONFileCmd(FileCmd):
     so we have to strip that final line before decoding the contents.
     """
     def __init__(self, *args, first_line_filter=None, last_line_filter=None,
-                 **kwargs):  # pylint: disable=W0613
+                 **kwargs):
         super().__init__(*args, **kwargs)
         if first_line_filter or last_line_filter:
             self.register_hook('pre-exec', self.format_json_contents)
@@ -501,9 +563,9 @@ class CephJSONFileCmd(FileCmd):
             self.first_line_filter = first_line_filter
             self.last_line_filter = last_line_filter
 
-    def format_json_contents(self, *args, **kwargs):  # pylint: disable=W0613
+    def format_json_contents(self, *_args, **_kwargs):
         if not os.path.exists(self.path):
-            raise SourceNotFound
+            raise SourceNotFound(self.path)
 
         with open(self.path) as f:
             lines = f.readlines()
@@ -521,7 +583,7 @@ class CephJSONFileCmd(FileCmd):
                 self.orig_path = self.path
                 self.path = tmp.name
 
-    def cleanup(self, output, **kwargs):  # pylint: disable=W0613
+    def cleanup(self, output, **_kwargs):
         """
         @param output: CmdOutput object
         """
@@ -684,6 +746,9 @@ class CLIHelperBase(HostHelpersBase):
             'apt_config_dump':
                 [BinCmd('apt-config dump'),
                  FileCmd('sos_commands/apt/apt-config_dump')],
+            'apparmor_status':
+                [BinCmd('apparmor_status'),
+                 FileCmd('sos_commands/apparmor/apparmor_status')],
             'ceph_daemon_osd_config_show':
                 [BinCmd('ceph daemon osd.{osd_id} config show',
                         json_decode=True),
@@ -892,52 +957,37 @@ class CLIHelperBase(HostHelpersBase):
                  FileCmd('sos_commands/networking/namespaces/{namespace}/'
                          'ip_netns_exec_{namespace}_ip_-d_address_show')],
             'ovn_nbctl_show':
-                [BinCmd('ovn-nbctl show'),
+                [BinCmd('ovn-nbctl --no-leader-only show'),
+                 FileCmd('sos_commands/ovn_central/'
+                         'ovn-nbctl_--no-leader-only_show'),
+                 # sosreport < 4.5
                  FileCmd('sos_commands/ovn_central/ovn-nbctl_show')],
             'ovn_sbctl_show':
-                [BinCmd('ovn-sbctl show'),
+                [BinCmd('ovn-sbctl --no-leader-only show'),
+                 FileCmd('sos_commands/ovn_central/'
+                         'ovn-sbctl_--no-leader-only_show'),
+                 # sosreport < 4.5
                  FileCmd('sos_commands/ovn_central/ovn-sbctl_show')],
-            'ovs_vsctl_get_Open_vSwitch':
-                [BinCmd('ovs-vsctl get Open_vSwitch . {record}',
+            'ovs_vsctl_get':
+                [BinCmd('ovs-vsctl get {table} {record} {column}',
                         singleline=True),
                  FileCmd('sos_commands/openvswitch/ovs-vsctl_-t_5_get_'
-                         'Open_vSwitch_._{record}', singleline=True)],
-            'ovs_vsctl_list_Open_vSwitch':
-                [BinCmd('ovs-vsctl list Open_vSwitch'),
+                         '{table}_{record}_{column}', singleline=True)],
+            'ovs_vsctl_list':
+                [BinCmd('ovs-vsctl list {table}'),
                  FileCmd('sos_commands/openvswitch/'
-                         'ovs-vsctl_-t_5_list_Open_vSwitch')],
-            'ovs_appctl_dpctl_show':
-                [BinCmd('ovs-appctl dpctl/show -s {datapath}'),
-                 OVSDPCTLFileCmd('sos_commands/openvswitch/'
-                                 'ovs-appctl_dpctl.show_-s_{datapath}')],
-            'ovs_appctl_dpctl_dump_conntrack':
-                [BinCmd('ovs-appctl dpctl/dump-conntrack -m {datapath}'),
-                 OVSDPCTLFileCmd(
-                            'sos_commands/openvswitch/'
-                            'ovs-appctl_dpctl.dump-conntrack_-m_{datapath}')],
-            'ovs_appctl_ofproto_list_tunnels':
-                [BinCmd('ovs-appctl ofproto/list-tunnels'),
-                 OVSDPCTLFileCmd('sos_commands/openvswitch/'
-                                 'ovs-appctl_ofproto.list-tunnels')],
+                         'ovs-vsctl_-t_5_list_{table}')],
             'ovs_vsctl_list_br':
                 [BinCmd('ovs-vsctl list-br'),
                  FileCmd('sos_commands/openvswitch/ovs-vsctl_-t_5_list-br')],
-            'ovs_ofctl_show':
-                [OVSOFCTLBinCmd('show {bridge}'),
-                 FileCmd('sos_commands/openvswitch/'
-                         'ovs-ofctl_-O_OpenFlow15_show_{bridge}'),
-                 FileCmd('sos_commands/openvswitch/'
-                         'ovs-ofctl_-O_OpenFlow14_show_{bridge}'),
-                 FileCmd('sos_commands/openvswitch/'
-                         'ovs-ofctl_-O_OpenFlow13_show_{bridge}'),
-                 FileCmd('sos_commands/openvswitch/'
-                         'ovs-ofctl_-O_OpenFlow12_show_{bridge}'),
-                 FileCmd('sos_commands/openvswitch/'
-                         'ovs-ofctl_-O_OpenFlow11_show_{bridge}'),
-                 FileCmd('sos_commands/openvswitch/'
-                         'ovs-ofctl_-O_OpenFlow10_show_{bridge}'),
-                 FileCmd('sos_commands/openvswitch/'
-                         'ovs-ofctl_show_{bridge}')],
+            'ovs_appctl':
+                [OVSAppCtlBinCmd('ovs-appctl {command} {flags} {args}'),
+                 OVSAppCtlFileCmd('sos_commands/openvswitch/ovs-appctl_'
+                                  '{command}{flags}{args}')],
+            'ovs_ofctl':
+                [OVSOFCtlBinCmd('{command} {args}'),
+                 OVSOFCtlFileCmd('sos_commands/openvswitch/'
+                                 'ovs-ofctl{ofversion}_{command}_{args}')],
             'pacemaker_crm_status':
                 [BinCmd('crm status'),
                  FileCmd('sos_commands/pacemaker/crm_status')],
