@@ -30,6 +30,10 @@ class BugTypeBase(abc.ABC, IssueTypeBase):
         pass
 
 
+class CVETypeBase(BugTypeBase):
+    ISSUE_TYPE = 'cve'
+
+
 class HotSOSScenariosWarning(IssueTypeBase):
     pass
 
@@ -166,6 +170,32 @@ class MAASWarning(IssueTypeBase):
     pass
 
 
+class VaultWarning(IssueTypeBase):
+    pass
+
+
+class UbuntuCVE(CVETypeBase):
+
+    @property
+    def base_url(self):
+        return 'https://ubuntu.com/security/'
+
+    @property
+    def url(self):
+        return "{}{}".format(self.base_url, self.id)
+
+
+class MitreCVE(CVETypeBase):
+
+    @property
+    def base_url(self):
+        return 'https://www.cve.org/CVERecord?id='
+
+    @property
+    def url(self):
+        return "{}{}".format(self.base_url, self.id)
+
+
 class LaunchpadBug(BugTypeBase):
 
     @property
