@@ -1,6 +1,7 @@
 from .common import (  # noqa: F403,F401
     OpenstackBase,
     OpenstackChecksBase,
-    OpenstackEventChecksBase,
+    OpenstackEventHandlerBase,
+    OpenstackEventCallbackBase,
 )
 from .openstack import OpenstackConfig  # noqa: F403,F401
