@@ -8,7 +8,7 @@ from hotsos.core.host_helpers.cli import CLIHelper, CmdBase
 from hotsos.core.host_helpers import (
     APTPackageHelper,
     DockerImageHelper,
-    DPKGVersionCompare,
+    DPKGVersion,
     PebbleHelper,
     SystemdHelper,
     SSLCertificate,
@@ -24,7 +24,7 @@ from hotsos.core.plugins.openstack.neutron import NeutronBase
 from hotsos.core.plugins.openstack.nova import NovaBase
 from hotsos.core.plugins.openstack.octavia import OctaviaBase
 from hotsos.core import plugintools
-from hotsos.core.ycheck.events import YEventCheckerBase
+from hotsos.core.ycheck.events import EventHandlerBase, EventCallbackBase
 
 
 class OpenstackBase(object):
@@ -35,56 +35,6 @@ class OpenstackBase(object):
         self.neutron = NeutronBase()
         self.octavia = OctaviaBase()
         self.certificate_expire_days = 60
-
-    @cached_property
-    def apache2_ssl_config_file(self):
-        return os.path.join(HotSOSConfig.data_root,
-                            'etc/apache2/sites-enabled',
-                            'openstack_https_frontend.conf')
-
-    @cached_property
-    def ssl_enabled(self):
-        return os.path.exists(self.apache2_ssl_config_file)
-
-    @cached_property
-    def _apache2_certificates(self):
-        """ Returns list of ssl cert paths relative to data_root. """
-        certificate_paths = []
-        if not self.ssl_enabled:
-            return certificate_paths
-
-        with open(self.apache2_ssl_config_file) as fd:
-            for line in fd:
-                ret = re.search(r'SSLCertificateFile /(\S+)', line)
-                if ret:
-                    path = ret.group(1)
-                    if path not in certificate_paths:
-                        certificate_paths.append(path)
-
-            return certificate_paths
-
-    @cached_property
-    def apache2_certificates_expiring(self):
-        apache2_certificates_expiring = []
-        max_days = self.certificate_expire_days
-        for path in self._apache2_certificates:
-            try:
-                ssl_checks = SSLCertificatesHelper(SSLCertificate(path),
-                                                   max_days)
-            except OSError:
-                log.info("cert path not found: %s", path)
-                continue
-
-            if ssl_checks.certificate_expires_soon:
-                apache2_certificates_expiring.append(path)
-
-        return apache2_certificates_expiring
-
-
-class OpenstackChecksBase(OpenstackBase, plugintools.PluginPartBase):
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
         self.ost_projects = OSTProjectCatalog()
         service_exprs = self.ost_projects.service_exprs
         self.pebble = PebbleHelper(service_exprs=service_exprs)
@@ -107,19 +57,19 @@ class OpenstackChecksBase(OpenstackBase, plugintools.PluginPartBase):
         return as a list of names. The list should normally have length 1.
         """
         relnames = set()
-        for pkg in OST_REL_INFO:
+        for pkg, values in OST_REL_INFO.items():
             if pkg in self.apt.core:
                 # Since the versions we match against will always match our
                 # version - 1 we use last known lt as current version.
                 v_lt = None
                 r_lt = None
-                pkg_ver = DPKGVersionCompare(self.apt.core[pkg])
-                for rel, ver in OST_REL_INFO[pkg].items():
+                pkg_ver = DPKGVersion(self.apt.core[pkg])
+                for rel, ver in values.items():
                     if pkg_ver > ver:
                         if v_lt is None:
                             v_lt = ver
                             r_lt = rel
-                        elif ver > DPKGVersionCompare(v_lt):
+                        elif ver > DPKGVersion(v_lt):
                             v_lt = ver
                             r_lt = rel
 
@@ -141,8 +91,14 @@ class OpenstackChecksBase(OpenstackBase, plugintools.PluginPartBase):
             # scenario check.
             return relnames[0]
 
-        relname = 'unknown'
+        relpath = os.path.join(HotSOSConfig.data_root,
+                               'etc/openstack-release')
+        # this exists as of Jammy/Yoga
+        if os.path.exists(relpath):
+            with open(relpath) as fd:
+                return fd.read().partition('=')[2]
 
+        relname = 'unknown'
         # fallback to uca version if exists
         if not os.path.exists(self.apt_source_path):
             return relname
@@ -220,16 +176,77 @@ class OpenstackChecksBase(OpenstackBase, plugintools.PluginPartBase):
 
         return False
 
+    @cached_property
+    def apache2_ssl_config_file(self):
+        return os.path.join(HotSOSConfig.data_root,
+                            'etc/apache2/sites-enabled',
+                            'openstack_https_frontend.conf')
+
+    @cached_property
+    def ssl_enabled(self):
+        return os.path.exists(self.apache2_ssl_config_file)
+
+    @cached_property
+    def _apache2_certificates(self):
+        """ Returns list of ssl cert paths relative to data_root. """
+        certificate_paths = []
+        if not self.ssl_enabled:
+            return certificate_paths
+
+        with open(self.apache2_ssl_config_file) as fd:
+            for line in fd:
+                ret = re.search(r'SSLCertificateFile /(\S+)', line)
+                if ret:
+                    path = ret.group(1)
+                    if path not in certificate_paths:
+                        certificate_paths.append(path)
+
+            return certificate_paths
+
+    @cached_property
+    def apache2_certificates_expiring(self):
+        apache2_certificates_expiring = []
+        max_days = self.certificate_expire_days
+        for path in self._apache2_certificates:
+            try:
+                ssl_checks = SSLCertificatesHelper(SSLCertificate(path),
+                                                   max_days)
+            except OSError:
+                log.info("cert path not found: %s", path)
+                continue
+
+            if ssl_checks.certificate_expires_soon:
+                apache2_certificates_expiring.append(path)
+
+        return apache2_certificates_expiring
+
+    @cached_property
+    def apache2_allow_encoded_slashes_on(self):
+        """ Returns True if AllowEncodedSlashes On is found. """
+        if not self.ssl_enabled:
+            return False
+
+        with open(self.apache2_ssl_config_file) as fd:
+            for line in fd:
+                if line.strip().startswith('#'):
+                    continue
+
+                ret = re.search(r'[Aa]llow[Ee]ncoded[Ss]lashes\s+[Oo]n', line)
+                if ret:
+                    return True
+        return False
+
+
+class OpenstackChecksBase(OpenstackBase, plugintools.PluginPartBase):
+    plugin_name = "openstack"
+    plugin_root_index = 4
+
     @property
     def plugin_runnable(self):
         return self.openstack_installed
 
 
-class OpenstackEventChecksBase(OpenstackChecksBase, YEventCheckerBase):
-    """
-    Normally we would call run_checks() here but the Openstack implementations
-    do run() themselves so we defer.
-    """
+class OpenstackEventCallbackBase(OpenstackBase, EventCallbackBase):
 
     def categorise_events(self, *args, **kwargs):
         if 'include_time' not in kwargs:
@@ -237,3 +254,7 @@ class OpenstackEventChecksBase(OpenstackChecksBase, YEventCheckerBase):
             kwargs['include_time'] = include_time
 
         return super().categorise_events(*args, **kwargs)
+
+
+class OpenstackEventHandlerBase(OpenstackChecksBase, EventHandlerBase):
+    pass
