@@ -1,10 +1,11 @@
 from hotsos.core import plugintools
+from hotsos.core.config import HotSOSConfig
 from hotsos.core.host_helpers import (
     APTPackageHelper,
     PebbleHelper,
     SystemdHelper,
 )
-from hotsos.core.ycheck.events import YEventCheckerBase
+from hotsos.core.ycheck.events import EventCallbackBase, EventHandlerBase
 from hotsos.core.utils import sorted_dict
 
 OVS_SERVICES_EXPRS = [r'ovsdb[a-zA-Z-]*',
@@ -25,6 +26,8 @@ PY_CLIENT_PREFIX = r"python3?-{}\S*"
 
 
 class OpenvSwitchChecksBase(plugintools.PluginPartBase):
+    plugin_name = "openvswitch"
+    plugin_root_index = 6
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -42,11 +45,21 @@ class OpenvSwitchChecksBase(plugintools.PluginPartBase):
         return len(self.apt.core) > 0
 
 
-class OpenvSwitchEventChecksBase(OpenvSwitchChecksBase, YEventCheckerBase):
+class OpenvSwitchEventCallbackBase(EventCallbackBase):
+
+    def categorise_events(self, *args, **kwargs):
+        if 'include_time' not in kwargs:
+            include_time = HotSOSConfig.event_tally_granularity == 'time'
+            kwargs['include_time'] = include_time
+
+        return super().categorise_events(*args, **kwargs)
+
+
+class OpenvSwitchEventHandlerBase(OpenvSwitchChecksBase, EventHandlerBase):
 
     @property
     def summary(self):
         # mainline all results into summary root
-        ret = self.load_and_run()
+        ret = self.run()
         if ret:
             return sorted_dict(ret)
