@@ -12,6 +12,7 @@ from hotsos.core.search import (
     SequenceSearchDef,
     SearchDef
 )
+from hotsos.core.utils import sort_suffixed_integers
 
 
 class BcacheConfig(ConfigBase):
@@ -175,24 +176,83 @@ class BcacheBase(StorageBase):
         return False
 
 
-class BDevsConfig(BcacheBase):
+class BDevsInfo(BcacheBase):
 
-    def get(self, key):
+    def _get_parameter(self, key):
+        all_values = []
+        for cset in self.cachesets:
+            for bdev in cset.bdevs:
+                all_values.append(bdev.cfg.get(key))
+
+        return all_values
+
+    @property
+    def sequential_cutoff(self):
         """
-        This currently assumes there is only one cacheset on the host.
+        @return: list of <str> sequential_cutoff from each bdev sorted in
+                 descending order. values can be int or float with our without
+                 a suffix e.g. '2' or '0.0k'.
         """
-        if self.cachesets and self.cachesets[0].bdevs:
-            return self.cachesets[0].bdevs[0].cfg.get(key)
+        ret = self._get_parameter("sequential_cutoff")
+        return sort_suffixed_integers(ret, reverse=True)
+
+    @property
+    def cache_mode(self):
+        """
+        @return: list of <str> cache_mode from each bdev sorted so that the
+                 settings with writeback mode selected are at the end of the
+                 list.
+        """
+        ret = self._get_parameter("cache_mode")
+        # send [writeback] to the end of the list
+        return sorted(ret,
+                      key='writethrough [writeback] writearound none'.__eq__)
+
+    @property
+    def writeback_percent(self):
+        """
+        @return: list of <int> writeback_percent from each bdev sorted in
+                 ascending order.
+        """
+        ret = self._get_parameter("writeback_percent")
+        # convert str to int
+        return sorted(list(map(int, ret)))
 
 
-class CachesetsConfig(BcacheBase):
+class CachesetsInfo(BcacheBase):
 
-    def get(self, key):
+    def _get_parameter(self, key):
+        return [cset.cfg.get(key) for cset in self.cachesets]
+
+    @property
+    def congested_read_threshold_us(self):
         """
-        This currently assumes there is only one cacheset on the host.
+        @return: list of <int> congested_read_threshold_us from each cacheset
+                 sorted in descending order.
         """
-        if self.cachesets:
-            return self.cachesets[0].cfg.get(key)
+        ret = self._get_parameter("congested_read_threshold_us")
+        # convert str to int
+        return sorted(list(map(int, ret)), reverse=True)
+
+    @property
+    def congested_write_threshold_us(self):
+        """
+        @return: list of <int> congested_write_threshold_us from each cacheset
+                 sorted in descending order.
+        """
+        ret = self._get_parameter("congested_write_threshold_us")
+        # convert str to int
+        return sorted(list(map(int, ret)), reverse=True)
+
+    @property
+    def cache_available_percent(self):
+        """
+        @return: list of <int> cache_available_percent from each cacheset
+                 sorted in ascending order.
+        """
+        ret = self._get_parameter("cache_available_percent")
+        # convert str to int
+        return sorted(list(map(int, ret)))
 
 
 class BcacheChecksBase(BcacheBase):
