@@ -12,9 +12,10 @@ from hotsos.core.host_helpers import (
     APTPackageHelper,
     CLIHelper,
     CLIHelperFile,
-    DPKGVersionCompare,
+    DPKGVersion,
     HostNetworkingHelper,
     PebbleHelper,
+    SnapPackageHelper,
     SystemdHelper,
     SectionalConfigBase,
 )
@@ -31,10 +32,11 @@ from hotsos.core.utils import (
     sorted_dict,
     seconds_to_date,
 )
-from hotsos.core.ycheck.events import YEventCheckerBase
+from hotsos.core.ycheck.events import EventCallbackBase
 
 CEPH_SERVICES_EXPRS = [r"ceph-[a-z0-9-]+",
-                       r"rados[a-z0-9-:]+"]
+                       r"rados[a-z0-9-:]+",
+                       r"microceph.(mon|mgr|mds|osd|rgw)"]
 CEPH_PKGS_CORE = [r"ceph",
                   r"rados",
                   r"rbd",
@@ -44,12 +46,13 @@ CEPH_PKGS_OTHER = []
 for ceph_pkg in CEPH_PKGS_CORE:
     CEPH_PKGS_OTHER.append(r"python3?-{}\S*".format(ceph_pkg))
 
-CEPH_LOGS = "var/log/ceph/"
+CEPH_SNAPS_CORE = [r'microceph']
 
 # NOTE(tpsilva): when updating this list, refer to the supported Ceph
 # versions for Ubuntu page:
 # https://ubuntu.com/ceph/docs/supported-ceph-versions
 CEPH_EOL_INFO = {
+    'reef': datetime(2034, 4, 30),
     'quincy': datetime(2032, 4, 30),
     'pacific': datetime(2024, 4, 30),
     'octopus': datetime(2030, 4, 30),
@@ -61,6 +64,7 @@ CEPH_EOL_INFO = {
 
 CEPH_REL_INFO = {
     'ceph-common': {
+        'reef': '18.0',
         'quincy': '17.0',
         'pacific': '16.0',
         'octopus': '15.0',
@@ -202,9 +206,9 @@ class CephCrushMap(object):
 
         bad_buckets = []
         buckets = self._build_buckets_from_crushdump(self.osd_crush_dump)
-        # check all bucket
-        for bid in buckets:
-            items = buckets[bid]["items"]
+        # check all buckets
+        for bdict in buckets.values():
+            items = bdict["items"]
             type_ids = []
             for item in items:
                 if item >= 0:
@@ -217,7 +221,7 @@ class CephCrushMap(object):
 
             # verify if the type_id list contain mixed type id
             if type_ids.count(type_ids[0]) != len(type_ids):
-                bad_buckets.append(buckets[bid]["name"])
+                bad_buckets.append(bdict["name"])
 
         return bad_buckets
 
@@ -333,6 +337,7 @@ class CephCluster(object):
     OSD_PG_MAX_LIMIT = 500
     OSD_PG_OPTIMAL_NUM_MAX = 200
     OSD_PG_OPTIMAL_NUM_MIN = 50
+    OSD_DISCREPANCY_ALLOWED = 5
     # If a pool's utilisation is below this value, we consider is "empty"
     POOL_EMPTY_THRESHOLD = 2
 
@@ -638,7 +643,7 @@ class CephCluster(object):
             return {}
 
         unique_versions = {}
-        for daemon_type in versions:
+        for daemon_type, count in versions.items():
             # skip the catchall
             if daemon_type == 'overall':
                 continue
@@ -648,7 +653,7 @@ class CephCluster(object):
                     continue
 
             unique_versions[daemon_type] = sorted(
-                list(set(versions[daemon_type])))
+                list(set(count)))
 
         return unique_versions
 
@@ -748,6 +753,27 @@ class CephCluster(object):
 
         return sorted(ssd_osds_using_bcache)
 
+    @cached_property
+    def osd_raw_usage_higher_than_data(self):
+        _bad_osds = []
+
+        if not self.osd_df_tree:
+            return _bad_osds
+
+        for osd in self.osd_df_tree['nodes']:
+            if osd['id'] >= 0:
+                raw_usage = osd['kb_used']
+                total_usage = osd['kb_used_data'] + osd['kb_used_omap'] + \
+                    osd['kb_used_meta']
+                # There's always some additional space used by OSDs that's not
+                # by data/omap/meta for journaling, internal structures, etc.
+                # Thus we allow 5% discrepancy.
+                allowance = total_usage * self.OSD_DISCREPANCY_ALLOWED / 100.0
+                if raw_usage > (total_usage + allowance):
+                    _bad_osds.append(osd['name'])
+
+        return sorted(_bad_osds)
+
 
 class CephDaemonBase(object):
 
@@ -903,10 +929,10 @@ class CephChecksBase(StorageBase):
         self.bcache = BcacheBase()
         self.apt = APTPackageHelper(core_pkgs=CEPH_PKGS_CORE,
                                     other_pkgs=CEPH_PKGS_OTHER)
+        self.snaps = SnapPackageHelper(core_snaps=CEPH_SNAPS_CORE)
         self.pebble = PebbleHelper(service_exprs=CEPH_SERVICES_EXPRS)
         self.systemd = SystemdHelper(service_exprs=CEPH_SERVICES_EXPRS)
         self.cluster = CephCluster()
-        self.lsof = Lsof()
 
     @property
     def summary_subkey(self):
@@ -914,7 +940,7 @@ class CephChecksBase(StorageBase):
 
     @property
     def plugin_runnable(self):
-        if self.apt.core:
+        if self.apt.core or self.snaps.core:
             return True
 
         return False
@@ -923,12 +949,18 @@ class CephChecksBase(StorageBase):
     def release_name(self):
         relname = 'unknown'
 
-        # First try from package version (TODO: add more)
         pkg = 'ceph-common'
-        if pkg in self.apt.core:
+        pkg_version = None
+        if self.apt.core and pkg in self.apt.core:
+            pkg_version = self.apt.core[pkg]
+        elif self.snaps.core and 'microceph' in self.snaps.core:
+            pkg_version = self.snaps.core['microceph']['version']
+            pkg_version = pkg_version.partition("+snap")[0]
+
+        if pkg_version is not None:
             for rel, ver in sorted(CEPH_REL_INFO[pkg].items(),
                                    key=lambda i: i[1], reverse=True):
-                if self.apt.core[pkg] > DPKGVersionCompare(ver):
+                if pkg_version > DPKGVersion(ver):
                     relname = rel
                     break
 
@@ -1090,7 +1122,7 @@ class CephChecksBase(StorageBase):
         """
         osds = {}
         tcmalloc_osds = 0
-        for row in self.lsof:
+        for row in Lsof():
             if row.COMMAND == 'ceph-osd':
                 osds[row.PID] = 1
                 if re.search("libtcmalloc", row.NAME):
@@ -1180,9 +1212,5 @@ class CephDaemonAllOSDsFactory(FactoryBase):
         return CephDaemonAllOSDsCommand(command)
 
 
-class CephEventChecksBase(CephChecksBase, YEventCheckerBase):
-
-    @property
-    def summary(self):
-        # mainline all results into summary root
-        return self.load_and_run()
+class CephEventCallbackBase(EventCallbackBase):
+    pass
