@@ -16,9 +16,14 @@ from hotsos.core.log import log
 
 class FileSearcher(_FileSearcher):
     def __init__(self, *args, **kwargs):
+        if HotSOSConfig.use_all_logs:
+            max_logrotate_depth = HotSOSConfig.max_logrotate_depth
+        else:
+            max_logrotate_depth = 1
+
         super().__init__(*args,
                          max_parallel_tasks=HotSOSConfig.max_parallel_tasks,
-                         max_logrotate_depth=HotSOSConfig.max_logrotate_depth,
+                         max_logrotate_depth=max_logrotate_depth,
                          **kwargs)
 
 
@@ -32,7 +37,7 @@ class SearchConstraintSearchSince(_SearchConstraintSearchSince):
             kwargs['days'] = days
 
         current_date = CLIHelper().date(format='+%Y-%m-%d %H:%M:%S')
-        if not current_date or type(current_date) != str:
+        if not current_date or not isinstance(current_date, str):
             log.error("current date '%s' being provided to search "
                       "constraints is not valid.", current_date)
             return
