@@ -30,7 +30,8 @@ class YDefsLoader(object):
             abs_path = os.path.join(path, entry)
             if os.path.isdir(abs_path):
                 subdefs = self._get_defs_recursive(abs_path)
-                defs[os.path.basename(abs_path)] = subdefs
+                if subdefs:
+                    defs[os.path.basename(abs_path)] = subdefs
             else:
                 if not self._is_def(abs_path):
                     continue
@@ -85,16 +86,6 @@ class YHandlerBase(object):
         @return: FileSearcher object to be used by this handler.
         """
 
-    @abc.abstractmethod
-    def load(self):
-        """
-        Load definitions from yaml in preparation for them to be processed.
-        """
-
     @abc.abstractmethod
     def run(self):
         """ Process operations. """
-
-    @abc.abstractmethod
-    def load_and_run(self):
-        """ Load and run. """
