@@ -1,10 +1,11 @@
+from functools import cached_property
+
+from propertree.propertree2 import PTreeLogicalGrouping
 from hotsos.core.log import log
 from hotsos.core.ycheck.engine.properties.common import (
-    cached_yproperty_attr,
     YPropertyOverrideBase,
     YPropertyMappedOverrideBase,
     YDefsSection,
-    add_to_property_catalog,
     YDefsContext,
 )
 from hotsos.core.ycheck.engine.properties.requires.requires import (
@@ -16,8 +17,49 @@ from hotsos.core.ycheck.engine.properties.search import (
 from hotsos.core.ycheck.engine.properties.inputdef import YPropertyInput
 
 
-@add_to_property_catalog
-class YPropertyCheck(YPropertyMappedOverrideBase):
+class CheckBase(object):
+
+    def fetch_item_result(self, item):
+        log.debug("%s: fetch_item_result() %s", self.__class__.__name__,
+                  item.__class__.__name__)
+        check = self.context['check']
+        if isinstance(item, YPropertySearch):
+            _results = check._search_results
+            check._set_search_cache_info(_results)
+            if not _results:
+                log.debug("check %s search has no matches so result=False",
+                          check.name)
+                return False
+
+            return True
+
+        if isinstance(item, YPropertyRequires):
+            result = item.result
+            if result or check.cache.requires is None:
+                check.cache.set('requires', item.cache)
+
+            return result
+
+        return item.result
+
+
+class CheckLogicalGrouping(CheckBase, PTreeLogicalGrouping):
+    _override_autoregister = False
+
+    @property
+    def result(self):
+        try:
+            return super().result
+        except Exception as exc:
+            log.exception("%s failed with exception: %s",
+                          self.__class__.__name__, exc)
+            raise
+
+
+class YPropertyCheck(CheckBase, YPropertyMappedOverrideBase):
+    _override_keys = ['check']
+    _override_members = [YPropertyRequires, YPropertySearch, YPropertyInput]
+    _override_logical_grouping_type = CheckLogicalGrouping
 
     @property
     def _search_results(self):
@@ -27,23 +69,40 @@ class YPropertyCheck(YPropertyMappedOverrideBase):
         search constraints requested.
         """
         global_results = self.context.search_results
-        if global_results is not None:
-            tag = self.search.unique_search_tag
-            _results = global_results.find_by_tag(tag)
-            log.debug("check %s has %s search results with tag %s",
-                      self.check_name, len(_results), tag)
-            return self.search.apply_extra_constraints(_results)
+        if global_results is None:
+            raise Exception("no search results provided to check '{}'".
+                            format(self.check_name))
 
-        raise Exception("no search results provided to check '{}'".
-                        format(self.check_name))
+        tag = self.search.unique_search_tag
 
-    @classmethod
-    def _override_keys(cls):
-        return ['check']
+        # first get simple search results
+        simple_results = global_results.find_by_tag(tag)
+        log.debug("check %s has %s simple search results with tag %s",
+                  self.check_name, len(simple_results), tag)
+        results = self.search.apply_extra_constraints(simple_results)
 
-    @classmethod
-    def _override_mapped_member_types(cls):
-        return [YPropertyRequires, YPropertySearch, YPropertyInput]
+        seq_def = self.search.cache.sequence_search
+        if not seq_def:
+            return results
+
+        # Not try for sequence search results
+        sections = global_results.find_sequence_by_tag(tag).values()
+        log.debug("check %s has %s sequence search results with tag %s",
+                  self.check_name, len(sections), tag)
+        if not sections:
+            return results
+
+        # Use the result of the first section start as the final
+        # result. This is enough for now because the section is guaranteed
+        # to be complete i.e. a full match and the result is ultimately
+        # True/False based on whether or not a result was found.
+        for result in list(sections)[0]:
+            if result.tag == seq_def.start_tag:
+                # NOTE: we don't yet support applying extra constraints here
+                results.append(result)
+                break
+
+        return results
 
     @property
     def name(self):
@@ -74,44 +133,43 @@ class YPropertyCheck(YPropertyMappedOverrideBase):
         files = [self.context.search_obj.resolve_source_id(s) for s in sources]
         self.search.cache.set('files', files)
 
-    def _result(self):
-        if self.search:
-            _results = self._search_results
-            self._set_search_cache_info(_results)
-            if not _results:
-                log.debug("check %s search has no matches so result=False",
-                          self.name)
-                return False
-
-            return True
-        if self.requires:
-            if self.cache.requires:
-                result = self.cache.requires.passes
-                log.debug("check %s - using cached result=%s", self.name,
-                          result)
-            else:
-                result = self.requires.passes
-                self.cache.set('requires', self.requires.cache)
-
-            return result
-
-        raise Exception("no supported properties found in check {}".format(
-                        self.name))
-
-    @cached_yproperty_attr
+    @cached_property
     def result(self):
-        log.debug("executing check %s", self.name)
-        result = self._result()
-        log.debug("check %s result=%s", self.name, result)
-        return result
+        try:
+            # Pass this object down to descendants so that they have access to
+            # its cache etc. Note this is modifying global context but since
+            # checks are processed sequentially this is fine.
+            self.context['check'] = self
+            log.debug("executing check %s", self.name)
+            results = []
+            stop_executon = False
+            for member in self.members:
+                for item in member:
+                    # Ignore these here as they are used by search properties.
+                    if isinstance(item, YPropertyInput):
+                        continue
+
+                    result = self.fetch_item_result(item)
+                    results.append(result)
+                    if CheckLogicalGrouping.is_exit_condition_met('and',
+                                                                  result):
+                        stop_executon = True
+                        break
+
+                if stop_executon:
+                    break
+
+            result = all(results)
+            log.debug("check %s (%s) result=%s", self.name, results, result)
+            return result
+        except Exception:
+            log.exception("something went wrong while executing check %s",
+                          self.name)
+            raise
 
 
-@add_to_property_catalog
 class YPropertyChecks(YPropertyOverrideBase):
-
-    @classmethod
-    def _override_keys(cls):
-        return ['checks']
+    _override_keys = ['checks']
 
     def initialise(self, local_vardefs, global_input, searcher, scenario):
         """
@@ -150,7 +208,7 @@ class YPropertyChecks(YPropertyOverrideBase):
         # provide results to each check object using global context
         self.check_context.search_obj = searcher
 
-    @cached_yproperty_attr
+    @cached_property
     def _checks(self):
         log.debug("parsing checks section")
         if not hasattr(self, 'check_context'):
@@ -159,6 +217,8 @@ class YPropertyChecks(YPropertyOverrideBase):
         resolved = []
         for name, content in self.content.items():
             s = YDefsSection(self._override_name, {name: {'check': content}},
+                             override_handlers=self.root.override_handlers,
+                             resolve_path=self._override_path,
                              context=self.check_context)
             for c in s.leaf_sections:
                 c.check.check_name = c.name
