@@ -1,36 +1,35 @@
+from functools import cached_property
+
+from propertree.propertree2 import (
+    PTreeLogicalGrouping,
+    PTreeOverrideLiteralType,
+)
 from hotsos.core.exceptions import ScenarioException
 from hotsos.core.issues import IssueContext
 from hotsos.core.log import log
 from hotsos.core.ycheck.engine.properties.common import (
-    cached_yproperty_attr,
     YPropertyOverrideBase,
     PropertyCacheRefResolver,
     YPropertyMappedOverrideBase,
-    LogicalCollectionHandler,
     YDefsSection,
-    add_to_property_catalog,
     YDefsContext,
 )
 
 
-@add_to_property_catalog
 class YPropertyPriority(YPropertyOverrideBase):
+    _override_keys = ['priority']
 
-    @classmethod
-    def _override_keys(cls):
-        return ['priority']
-
-    @cached_yproperty_attr
-    def value(self):
+    def __int__(self):
         return int(self.content or 1)
 
 
-@add_to_property_catalog
 class YPropertyRaises(YPropertyOverrideBase):
+    _override_keys = ['raises']
 
-    @classmethod
-    def _override_keys(cls):
-        return ['raises']
+    @property
+    def cve_id(self):
+        """ optional setting. """
+        return self.content.get('cve-id')
 
     @property
     def bug_id(self):
@@ -53,7 +52,9 @@ class YPropertyRaises(YPropertyOverrideBase):
         if not fdict:
             return self.message
 
-        for key, value in fdict.items():  # pylint: disable=E1101
+        fdict = dict(fdict)
+
+        for key, value in fdict.items():
             if PropertyCacheRefResolver.is_valid_cache_ref(value):
                 rvalue = PropertyCacheRefResolver(value,
                                                   pcrr_vars=self.context.vars,
@@ -68,7 +69,7 @@ class YPropertyRaises(YPropertyOverrideBase):
 
         return message
 
-    @cached_yproperty_attr
+    @cached_property
     def format_dict(self):
         """
         Optional dict of key/val pairs used to format the message string.
@@ -99,7 +100,7 @@ class YPropertyRaises(YPropertyOverrideBase):
 
         return fdict
 
-    @cached_yproperty_attr
+    @cached_property
     def type(self):
         """ Name of core.issues.IssueTypeBase object and will be used to raise
         an issue or bug using message as argument. """
@@ -107,50 +108,70 @@ class YPropertyRaises(YPropertyOverrideBase):
         return self.get_cls(_type)
 
 
-class YPropertyDecisionBase(YPropertyMappedOverrideBase,
-                            LogicalCollectionHandler):
+class DecisionBase(object):
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.checks_instances = None
-
-    @classmethod
-    def _override_mapped_member_types(cls):
-        return []
-
-    def add_checks_instances(self, checks):
-        self.checks_instances = checks
-
-    def get_item_result_callback(self, item, is_default_group=False):
-        name = str(item)
-        if name not in self.checks_instances:
-            raise Exception("no check found with name {}".format(name))
-
-        return self.checks_instances[name].result
+    def get_check_item(self, name):
+        checks = self.context.checks
+        try:
+            log.debug("%s: get_check_item() %s", self.__class__.__name__,
+                      name)
+            return checks[name]
+        except KeyError:
+            log.exception("check '%s' not found in %s", name, checks)
 
 
-class YPropertyDecisionLogicalGroupsExtension(YPropertyDecisionBase):
+class DecisionLogicalGrouping(DecisionBase, PTreeLogicalGrouping):
+    _override_autoregister = False
 
-    @classmethod
-    def _override_keys(cls):
-        return LogicalCollectionHandler.VALID_GROUP_KEYS
+    def get_items(self):
+        items = []
+        for item in super().get_items():
+            if isinstance(item, PTreeOverrideLiteralType):
+                item = self.get_check_item(str(item))
+
+            items.append(item)
+
+        log.debug("%s: items: %s", self.__class__.__name__, items)
+        return items
 
 
-@add_to_property_catalog
-class YPropertyDecision(YPropertyDecisionBase):
+class YPropertyDecision(DecisionBase, YPropertyMappedOverrideBase):
+    _override_keys = ['decision']
+    # no members, we are using a mapping to get a custom PTreeLogicalGrouping
+    _override_members = []
+    _override_logical_grouping_type = DecisionLogicalGrouping
 
-    @classmethod
-    def _override_keys(cls):
-        return ['decision']
+    @property
+    def result(self):
+        results = []
+        try:
+            stop_executon = False
+            for member in self.members:
+                for item in member:
+                    if isinstance(item, PTreeOverrideLiteralType):
+                        item = self.get_check_item(str(item))
 
-    @classmethod
-    def _override_mapped_member_types(cls):
-        return super()._override_mapped_member_types() + \
-                    [YPropertyDecisionLogicalGroupsExtension]
+                    result = item.result
+                    results.append(result)
+                    if DecisionLogicalGrouping.is_exit_condition_met('and',
+                                                                     result):
+                        stop_executon = True
+                        break
+
+                if stop_executon:
+                    break
+
+            result = all(results)
+            log.debug("decision: %s result=%s", results, result)
+            return result
+        except Exception:
+            log.exception("something went wrong when executing decision")
+            raise
 
 
-@add_to_property_catalog
 class YPropertyConclusion(YPropertyMappedOverrideBase):
+    _override_keys = ['conclusion']
+    _override_members = [YPropertyPriority, YPropertyDecision, YPropertyRaises]
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -159,14 +180,6 @@ class YPropertyConclusion(YPropertyMappedOverrideBase):
         # will be retrievable as machine readable output.
         self.issue_context = IssueContext()
 
-    @classmethod
-    def _override_keys(cls):
-        return ['conclusion']
-
-    @classmethod
-    def _override_mapped_member_types(cls):
-        return [YPropertyPriority, YPropertyDecision, YPropertyRaises]
-
     @property
     def name(self):
         if hasattr(self, 'conclusion_name'):
@@ -177,47 +190,44 @@ class YPropertyConclusion(YPropertyMappedOverrideBase):
         Return True/False result of this conclusion and prepare issue info.
         """
         log.debug("running conclusion %s", self.name)
-        self.decision.add_checks_instances(checks)
         log.debug("decision:start")
-        result = self.decision.run_collection()
+        result = self.decision.result
         log.debug("decision:end")
         if not result:
             return False
 
+        cve_id = self.raises.cve_id
         bug_id = self.raises.bug_id
         bug_type = self.raises.type.ISSUE_TYPE
-        is_bug_type = bug_type == 'bug'
-        if ((is_bug_type and bug_id is None) or
-                (bug_id is not None and not is_bug_type)):
-            msg = ("both bug-id (current={}) and bug type (current={}) "
-                   "required in order to raise a bug".format(bug_id, bug_type))
-            raise ScenarioException(msg)
+        is_bug_type = bug_type in ('bug', 'cve')
+        if cve_id or bug_id or is_bug_type:
+            if not (all([bug_id, bug_type == 'bug']) or
+                    all([cve_id, bug_type == 'cve'])):
+                msg = ("both cve-id/bug-id (current={}) and bug type "
+                       "(current={}) required in order to raise a bug".
+                       format(bug_id or cve_id, bug_type))
+                raise ScenarioException(msg)
 
         message = self.raises.message_formatted(checks=checks)
-        if self.raises.type.ISSUE_TYPE == 'bug':
-            self.issue = self.raises.type(self.raises.bug_id, message)
+        if is_bug_type:
+            self.issue = self.raises.type(bug_id or cve_id, message)
         else:
             self.issue = self.raises.type(message)
 
         return result
 
 
-@add_to_property_catalog
 class YPropertyConclusions(YPropertyOverrideBase):
+    _override_keys = ['conclusions']
 
-    @classmethod
-    def _override_keys(cls):
-        return ['conclusions']
-
-    def initialise(self, ypvars):
+    def initialise(self, ypvars, checks):
         """
         Perform initialisation tasks for this set of conclusions.
-
-        * create conclusions context containing vars
         """
-        self.conclusion_context = YDefsContext({'vars': ypvars})
+        self.conclusion_context = YDefsContext({'vars': ypvars,
+                                                'checks': checks})
 
-    @cached_yproperty_attr
+    @cached_property
     def _conclusions(self):
         log.debug("parsing conclusions section")
         if not hasattr(self, 'conclusion_context'):
@@ -227,6 +237,8 @@ class YPropertyConclusions(YPropertyOverrideBase):
         for name, content in self.content.items():
             s = YDefsSection(self._override_name,
                              {name: {'conclusion': content}},
+                             override_handlers=self.root.override_handlers,
+                             resolve_path=self._override_path,
                              context=self.conclusion_context)
             for c in s.leaf_sections:
                 c.conclusion.conclusion_name = c.name
