@@ -17,8 +17,8 @@ def intercept_exception(f):
     def intercept_exception_inner(*args, **kwargs):
         try:
             return f(*args, **kwargs)
-        except Exception:
-            log.exception("function %s raised exception:", f.__name__)
+        except Exception as exc:
+            log.error("function '%s' raised exception: %s", f.__name__, exc)
             raise
 
     return intercept_exception_inner
@@ -38,9 +38,9 @@ class CheckItemsBase(abc.ABC):
 
     def __init__(self, raw):
         self._items = {}
-        if type(raw) == dict:
+        if isinstance(raw, dict):
             self._items = raw
-        elif type(raw) == list:
+        elif isinstance(raw, list):
             self._items = {i: None for i in raw}
         else:
             self._items = {raw: None}
@@ -68,7 +68,7 @@ class PackageCheckItemsBase(CheckItemsBase):
     def installed(self):
         _installed = []
         for p in self.packages_to_check:
-            if self.packaging_helper.is_installed(p):  # pylint: disable=E1101
+            if self.packaging_helper.is_installed(p):
                 _installed.append(p)
 
         return _installed
@@ -92,7 +92,7 @@ class OpsUtils(object):
         for op in ops:
             item = str(op[0])
             if len(op) > 1:
-                if type(op[1]) == str:
+                if isinstance(op[1], str):
                     item = "{} \"{}\"".format(item, op[1])
                 else:
                     item = "{} {}".format(item, op[1])
@@ -115,7 +115,7 @@ class OpsUtils(object):
 
             return getattr(operator, op)(opinput)
         except Exception:
-            log.exception("failed to apply operator '%s'", op)
+            log.error("failed to apply operator '%s'", op)
             raise
 
     def apply_ops(self, ops, opinput=None, normalise_value_types=False):
@@ -131,7 +131,7 @@ class OpsUtils(object):
                                       value.
         """
         log.debug("ops=%s, input=%s", ops, opinput)
-        if type(ops) != list:
+        if not isinstance(ops, list):
             raise Exception("Expected list of ops but got {}".
                             format(ops))
 
@@ -145,9 +145,9 @@ class OpsUtils(object):
                 expected = op[1]
 
                 if expected is not None:
-                    if type(expected) == str and expected.startswith("$"):
+                    if isinstance(expected, str) and expected.startswith("$"):
                         varname = expected.partition("$")[2]
-                        varval = self.context.vars.resolve(varname)  # noqa, pylint: disable=E1101
+                        varval = self.context.vars.resolve(varname)
                         expected = varval
 
                     if normalise_value_types:
@@ -159,10 +159,11 @@ class OpsUtils(object):
             opinput = self._apply_op(op[0], opinput=opinput, expected=expected,
                                      force_expected=force_expected)
 
-        return opinput
+        return bool(opinput)
 
 
 class YRequirementTypeBase(YPropertyOverrideBase, OpsUtils):
+    _overrride_autoregister = False
 
     @property
     @abc.abstractmethod
@@ -172,13 +173,14 @@ class YRequirementTypeBase(YPropertyOverrideBase, OpsUtils):
         Returns True if met otherwise False.
         """
 
-    def __call__(self):
+    @property
+    def result(self):
         try:
             return self._result
         except Exception:
             # display traceback here before it gets swallowed up.
-            log.exception("requires.%s.result raised the following",
-                          self.__class__.__name__)
+            log.error("requires.%s.result raised the following",
+                      self.__class__.__name__)
             raise
 
 
@@ -190,7 +192,7 @@ class YRequirementTypeWithOpsBase(YRequirementTypeBase):
 
     @property
     def ops(self):
-        if type(self.content) != dict:
+        if not isinstance(self.content, dict):
             return self.default_ops
 
         return self.content.get('ops', self.default_ops)
@@ -202,7 +204,7 @@ class ServiceCheckItemsBase(CheckItemsBase):
     def _started_after_services(self):
         svcs = []
         for _, settings in self:
-            if type(settings) != dict:
+            if not isinstance(settings, dict):
                 continue
 
             svc = settings.get('started-after')
