@@ -7,15 +7,13 @@ from hotsos.core.ycheck.engine.properties.requires import (
 
 class YRequirementTypeProperty(YRequirementTypeWithOpsBase):
     """ Provides logic to perform checks on Python Properties. """
-
-    @classmethod
-    def _override_keys(cls):
-        return ['property']
+    _override_keys = ['property']
+    _overrride_autoregister = True
 
     @property
     @intercept_exception
     def _result(self):
-        if type(self.content) != dict:
+        if not isinstance(self.content, dict):
             path = self.content
         else:
             path = self.content['path']
