@@ -56,24 +56,32 @@ class YScenarioChecker(YHandlerBase):
 
         yscenarios = YDefsSection(HotSOSConfig.plugin_name, plugin_content)
         if (not HotSOSConfig.force_mode and yscenarios.requires and not
-                yscenarios.requires.passes):
+                yscenarios.requires.result):
             log.debug("plugin '%s' scenarios pre-requisites not met - "
                       "skipping", HotSOSConfig.plugin_name)
             return
 
         log.debug("sections=%s, scenarios=%s",
-                  len(yscenarios.branch_sections),
-                  len(yscenarios.leaf_sections))
+                  len(list(yscenarios.branch_sections)),
+                  len(list(yscenarios.leaf_sections)))
 
         to_skip = set()
 
         checks = []
         for scenario in yscenarios.leaf_sections:
+            fullname = "{}.{}.{}".format(HotSOSConfig.plugin_name,
+                                         scenario.parent.name, scenario.name)
+            if (HotSOSConfig.scenario_filter and
+                    fullname != HotSOSConfig.scenario_filter):
+                log.info("skipping scenario %s (filter=%s)", fullname,
+                         HotSOSConfig.scenario_filter)
+                continue
+
             # Only register scenarios if requirements are satisfied.
             group_name = scenario.parent.name
             if (not HotSOSConfig.force_mode and
                     (group_name in to_skip or
-                        (scenario.requires and not scenario.requires.passes))):
+                        (scenario.requires and not scenario.requires.result))):
                 log.debug("%s requirements not met - skipping scenario %s",
                           group_name, scenario.name)
                 to_skip.add(group_name)
@@ -82,10 +90,10 @@ class YScenarioChecker(YHandlerBase):
             checks.append(scenario.checks)
             scenario.checks.initialise(scenario.vars, scenario.input,
                                        self.searcher, scenario)
-            scenario.conclusions.initialise(scenario.vars)
-            self._scenarios.append(Scenario(scenario.name,
-                                            scenario.checks,
-                                            scenario.conclusions))
+            _scenario = Scenario(scenario.name, scenario.checks,
+                                 scenario.conclusions)
+            scenario.conclusions.initialise(scenario.vars, _scenario.checks)
+            self._scenarios.append(_scenario)
 
         log.debug("executing check searches")
         results = self.searcher.run()
@@ -99,22 +107,25 @@ class YScenarioChecker(YHandlerBase):
     def _run_scenario_conclusion(self, scenario, issue_mgr):
         """ Determine the conclusion of this scenario. """
         results = {}
-        # run all conclusions and use highest priority result(s). One or
-        # more conclusions may share the same priority. All conclusions
-        # that match and share the same priority will be used.
-        for name, conc in scenario.conclusions.items():
-            if conc.reached(scenario.checks):
-                if conc.priority:
-                    priority = conc.priority.value
-                else:
-                    priority = 1
+        # Run conclusions in order of priority. One or more conclusion may
+        # share the same priority. If one or more conclusion of the same
+        # priority is reached the rest (of lower priority) are ignored.
+        last_priority = None
+        for conc in sorted(scenario.conclusions.values(), key=lambda _conc:
+                           int(_conc.priority or 1), reverse=True):
+            priority = int(conc.priority or 1)
+            if last_priority is not None:
+                if priority < last_priority and last_priority in results:
+                    break
 
+            last_priority = priority
+            if conc.reached(scenario.checks):
                 if priority in results:
                     results[priority].append(conc)
                 else:
                     results[priority] = [conc]
 
-                log.debug("conclusion reached: %s (priority=%s)", name,
+                log.debug("conclusion reached: %s (priority=%s)", conc.name,
                           priority)
 
         if results:
@@ -126,7 +137,10 @@ class YScenarioChecker(YHandlerBase):
         else:
             log.debug("no conclusions reached")
 
-    def run(self):
+    def run(self, load=True):
+        if load:
+            self.load()
+
         failed_scenarios = []
         issue_mgr = IssuesManager()
         for scenario in self.scenarios:
@@ -144,7 +158,3 @@ class YScenarioChecker(YHandlerBase):
                    "debug mode (--debug) to get more detail".
                    format(', '.join(failed_scenarios)))
             issue_mgr.add(HotSOSScenariosWarning(msg))
-
-    def load_and_run(self):
-        self.load()
-        return self.run()
