@@ -1,26 +1,22 @@
 from hotsos.core.plugins.lxd import LXD, LXDChecksBase
-from hotsos.core.plugintools import summary_entry_offset as idx
 
 
 class LXDSummary(LXDChecksBase):
+    summary_part_index = 0
 
-    @idx(0)
-    def __summary_services(self):
+    def __0_summary_services(self):
         if self.systemd.services:
             return self.systemd.summary
 
-    @idx(1)
-    def __summary_snaps(self):
+    def __1_summary_snaps(self):
         if self.snaps:
             return self.snaps.all_formatted
 
-    @idx(2)
-    def __summary_dpkg(self):
+    def __2_summary_dpkg(self):
         if self.apt:
             return self.apt.all_formatted
 
-    @idx(3)
-    def __summary_instances(self):
+    def __3_summary_instances(self):
         instances = LXD().instances
         if instances:
             return instances
