@@ -13,41 +13,33 @@ from hotsos.core.issues import (
 from hotsos.core.log import log
 from hotsos.core.plugins.openstack.common import (
     OpenstackChecksBase,
-    OpenstackEventChecksBase,
+    OpenstackEventHandlerBase,
+    OpenstackEventCallbackBase,
 )
 from hotsos.core.plugins.openstack.neutron import NeutronHAInfo
-from hotsos.core.plugintools import summary_entry_offset as idx
 from hotsos.core.search import (
     FileSearcher,
     SearchConstraintSearchSince,
 )
 from hotsos.core import utils
 from hotsos.core.utils import sorted_dict
-from hotsos.core.ycheck.events import CallbackHelper
 from hotsos.core.ycheck.engine.properties.search import CommonTimestampMatcher
 
-EVENTCALLBACKS = CallbackHelper()
 VRRP_TRANSITION_WARN_THRESHOLD = 8
 
 
-class ApacheEventChecks(OpenstackEventChecksBase):
+class ApacheEventCallback(OpenstackEventCallbackBase):
+    event_group = 'apache'
+    event_names = ['connection-refused']
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(EVENTCALLBACKS, *args, **kwargs)
-
-    @property
-    def root_group_name(self):
-        return 'apache'
-
-    @EVENTCALLBACKS.callback(event_group='apache')
-    def connection_refused(self, event):
+    def __call__(self, event):
         ports_max = {}
         context = {}
 
         results = []
         for result in event.results:
             # save some context info
-            path = self.searcher.resolve_source_id(result.source_id)
+            path = event.searcher.resolve_source_id(result.source_id)
             if path in context:
                 context[path].append(result.linenumber)
             else:
@@ -84,47 +76,44 @@ class ApacheEventChecks(OpenstackEventChecksBase):
 
         return sorted_dict(conns_refused)
 
-    def __summary_apache(self):
+
+class ApacheEventChecks(OpenstackEventHandlerBase):
+    event_group = 'apache'
+
+    def __104_summary_apache(self):
         return self.final_event_results
 
 
-class APIEvents(OpenstackEventChecksBase):
+class APIEventsCallback(OpenstackEventCallbackBase):
+    event_group = 'http-requests'
+    event_names = ['neutron']
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(EVENTCALLBACKS, *args, **kwargs)
-
-    @property
-    def root_group_name(self):
-        return 'http-requests'
-
-    @EVENTCALLBACKS.callback(event_group='http-requests',
-                             event_names=['neutron'])
-    def http_requests(self, event):
+    def __call__(self, event):
         results = [{'date': r.get(1),
                     'key': r.get(2)} for r in event.results]
         ret = self.categorise_events(event, results=results)
         if ret:
             return ret
 
-    def __summary_http_requests(self):
+
+class APIEvents(OpenstackEventHandlerBase):
+    event_group = 'http-requests'
+
+    def __105_summary_http_requests(self):
         out = self.final_event_results
         if out:
             return out
 
 
-class NeutronAgentEventChecks(OpenstackEventChecksBase):
-    """
-    Loads events we want to check from definitions yaml and executes them. The
-    results are sorted by date and the "top 5" are presented along with stats
-    on the full set of samples.
-    """
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(EVENTCALLBACKS, *args, **kwargs)
-
-    @property
-    def root_group_name(self):
-        return 'neutron.agents'
+class AgentEventsCallback(OpenstackEventCallbackBase):
+    event_group = 'neutron.agents'
+    ovsdbapp_event_names = ['ovsdbapp-nb-leader-reconnect',
+                            'ovsdbapp-sb-leader-reconnect']
+    ovn_mech_driver_events = ['ovn-resource-revision-bump',
+                              'ovsdb-monitor-router-binding-transitions',
+                              'ovsdb-transaction-aborted']
+    event_names = ['rpc-loop', 'router-spawn-events', 'router-updates']
+    event_names += ovsdbapp_event_names + ovn_mech_driver_events
 
     def _get_event_stats(self, results, tag_prefix, custom_idxs=None):
         stats = LogEventStats(results, tag_prefix, custom_idxs=custom_idxs)
@@ -136,111 +125,163 @@ class NeutronAgentEventChecks(OpenstackEventChecksBase):
         return {"top": top5,
                 "stats": stats.get_event_stats()}
 
-    @EVENTCALLBACKS.callback(event_group='neutron.agents')
-    def router_updates(self, event):
+    def __call__(self, event):
         agent = event.section
-        sri = SearchResultIndices(event_id_idx=4,
-                                  metadata_idx=3,
-                                  metadata_key='router')
-        ret = self._get_event_stats(event.results, event.search_tag,
-                                    custom_idxs=sri)
-        if ret:
-            return {event.name: ret}, agent
+        if event.name == 'ovsdb-monitor-router-binding-transitions':
+            # The ovsdbmonitor will print bindings which will eventually
+            # reflect transitions so we need to filter out contiguous bindings
+            # to the same chassis so that we are just left with transitions
+            # that we can then count.
+            results = []
+            for r in event.results:
+                results.append({'date': r.get(1), 'time': r.get(2),
+                                'router': r.get(3), 'key': r.get(4)})
 
-    @EVENTCALLBACKS.callback(event_group='neutron.agents',
-                             event_names=['rpc-loop', 'router-spawn-events'])
-    def process_events(self, event):
-        agent = event.section
-        ret = self._get_event_stats(event.results, event.search_tag)
-        if ret:
-            return {event.name: ret}, agent
+            results = sorted(results,
+                             key=lambda e:
+                             datetime.datetime.strptime(
+                                 "{} {}".format(e['date'],
+                                                e['time']),
+                                 '%Y-%m-%d %H:%M:%S'))
 
-    def __summary_neutron_l3_agent(self):
+            new_results = []
+            last_known = {}
+            host_key = 'key'
+            for item in results:
+                router = item['router']
+                if router not in last_known:
+                    last_known[router] = item
+                elif last_known[router][host_key] != item[host_key]:
+                    # remember hosts port transitioned from
+                    new_results.append(last_known[router])
+                    last_known[router] = item
+
+            ret = self.categorise_events(event, results=new_results)
+            if ret:
+                return {event.name: ret}, agent
+        elif event.name in self.ovsdbapp_event_names + \
+                self.ovn_mech_driver_events:
+            if event.name == 'ovn-resource-revision-bump':
+                ret = self.categorise_events(event, max_results_per_date=5)
+            elif event.name == 'ovsdb-transaction-aborted':
+                ret = {}
+                for result in event.results:
+                    _date = result.get(1)
+                    if _date in ret:
+                        ret[_date] += 1
+                    else:
+                        ret[_date] = 1
+
+                ret = sorted_dict(ret)
+            else:
+                ret = self.categorise_events(event)
+
+            if ret:
+                return {event.name: ret}, agent
+        elif event.name in ['rpc-loop', 'router-spawn-events']:
+            ret = self._get_event_stats(event.results, event.search_tag)
+            if ret:
+                return {event.name: ret}, agent
+        else:
+            sri = SearchResultIndices(event_id_idx=4,
+                                      metadata_idx=3,
+                                      metadata_key='router')
+            ret = self._get_event_stats(event.results, event.search_tag,
+                                        custom_idxs=sri)
+            if ret:
+                return {event.name: ret}, agent
+
+
+class NeutronAgentEventChecks(OpenstackEventHandlerBase):
+    """
+    Loads events we want to check from definitions yaml and executes them. The
+    results are sorted by date and the "top 5" are presented along with stats
+    on the full set of samples.
+    """
+    event_group = 'neutron.agents'
+
+    # NOTE: can share summary index with l3 agent since they will never be
+    #       colocated.
+    def __102_summary_neutron_server(self):
+        out = self.final_event_results or {}
+        return out.get('neutron-server')
+
+    def __102_summary_neutron_l3_agent(self):
         out = self.final_event_results or {}
         return out.get('neutron-l3-agent')
 
-    def __summary_neutron_ovs_agent(self):
+    def __103_summary_neutron_ovs_agent(self):
         out = self.final_event_results or {}
         return out.get('neutron-ovs-agent')
 
 
-class OctaviaAgentEventChecks(OpenstackEventChecksBase):
+class OctaviaAgentEventsCallback(OpenstackEventCallbackBase):
+    event_group = 'octavia'
+    event_names = ['lb-failover-auto', 'lb-failover-manual',
+                   'amp-missed-heartbeats']
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(EVENTCALLBACKS, *args, **kwargs)
+    def __call__(self, event):
+        if event.name in ['lb-failover-auto', 'lb-failover-manual']:
+            results = []
+            for e in event.results:
+                payload = yaml.safe_load(e.get(3))
+                lb_id = payload.get('load_balancer_id')
+                if lb_id is None:
+                    continue
 
-    @property
-    def root_group_name(self):
-        return 'octavia'
+                results.append({'date': e.get(1), 'time': e.get(2),
+                                'key': lb_id})
 
-    @EVENTCALLBACKS.callback(event_group='octavia',
-                             event_names=['lb-failover-auto',
-                                          'lb-failover-manual'])
-    def lb_failovers(self, event):
-        results = []
-        for e in event.results:
-            payload = yaml.safe_load(e.get(3))
-            lb_id = payload.get('load_balancer_id')
-            if lb_id is None:
-                continue
+            ret = self.categorise_events(event, results=results,
+                                         key_by_date=False)
+            if ret:
+                failover_type = event.name.rpartition('-')[2]
+                return {failover_type: ret}, 'lb-failovers'
+        else:
+            missed_heartbeats = self.categorise_events(event,
+                                                       key_by_date=False)
+            if not missed_heartbeats:
+                return
 
-            results.append({'date': e.get(1), 'time': e.get(2), 'key': lb_id})
+            # sort each amp by occurences
+            for ts_date, amps in missed_heartbeats.items():
+                amps_sorted = utils.sorted_dict(amps, key=lambda e: e[1],
+                                                reverse=True)
+                missed_heartbeats[ts_date] = amps_sorted
 
-        ret = self.categorise_events(event, results=results, key_by_date=False)
-        if ret:
-            failover_type = event.name.rpartition('-')[2]
-            return {failover_type: ret}, 'lb-failovers'
+            # then sort by date
+            return utils.sorted_dict(missed_heartbeats)
 
-    @EVENTCALLBACKS.callback(event_group='octavia')
-    def amp_missed_heartbeats(self, event):
-        missed_heartbeats = self.categorise_events(event, key_by_date=False)
-        if not missed_heartbeats:
-            return
 
-        # sort each amp by occurences
-        for ts_date, amps in missed_heartbeats.items():
-            missed_heartbeats[ts_date] = utils.sorted_dict(amps,
-                                                           key=lambda e: e[1],
-                                                           reverse=True)
+class OctaviaAgentEventChecks(OpenstackEventHandlerBase):
+    event_group = 'octavia'
 
-        # then sort by date
-        return utils.sorted_dict(missed_heartbeats)
-
-    def __summary_octavia(self):
+    def __106_summary_octavia(self):
         return self.final_event_results
 
 
-class NovaComputeEventChecks(OpenstackEventChecksBase):
+class PCINotFoundCallback(OpenstackEventCallbackBase):
+    event_group = 'nova.nova-compute'
+    event_names = ['pci-dev-not-found']
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(EVENTCALLBACKS, *args, **kwargs)
-
-    @property
-    def root_group_name(self):
-        return 'nova.nova-compute'
-
-    @EVENTCALLBACKS.callback(event_group='nova.nova-compute')
-    def pci_dev_not_found(self, event):
+    def __call__(self, event):
         ret = self.categorise_events(event)
         if ret:
             return ret, 'PciDeviceNotFoundById'
 
-    def __summary_nova(self):
+
+class NovaComputeEventChecks(OpenstackEventHandlerBase):
+    event_group = 'nova.nova-compute'
+
+    def __107_summary_nova(self):
         return self.final_event_results
 
 
-class AgentApparmorChecks(OpenstackEventChecksBase):
+class ApparmorCallback(OpenstackEventCallbackBase):
+    event_group = 'apparmor'
+    event_names = ['nova', 'neutron']
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(EVENTCALLBACKS, *args, **kwargs)
-
-    @property
-    def root_group_name(self):
-        return 'apparmor'
-
-    @EVENTCALLBACKS.callback(event_group='apparmor',
-                             event_names=['nova', 'neutron'])
-    def openstack_apparmor(self, event):
+    def __call__(self, event):
         results = [{'date': "{} {}".format(r.get(1), r.get(2)),
                     'time': r.get(3),
                     'key': r.get(4)} for r in event.results]
@@ -251,20 +292,17 @@ class AgentApparmorChecks(OpenstackEventChecksBase):
             # action.
             return {event.name: ret}, event.section
 
-    def __summary_apparmor(self):
+
+class AgentApparmorChecks(OpenstackEventHandlerBase):
+    event_group = 'apparmor'
+
+    def __108_summary_apparmor(self):
         return self.final_event_results
 
 
-class NeutronL3HAEventChecks(OpenstackEventChecksBase):
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(EVENTCALLBACKS, *args, **kwargs)
-        self.cli = CLIHelper()
-        self.ha_info = NeutronHAInfo()
-
-    @property
-    def root_group_name(self):
-        return 'neutron.ml2-routers'
+class L3HACallback(OpenstackEventCallbackBase):
+    event_group = 'neutron.ml2-routers'
+    event_names = ['vrrp-transitions']
 
     def check_vrrp_transitions(self, transitions):
         # there will likely be a large number of transitions if we look across
@@ -289,20 +327,10 @@ class NeutronL3HAEventChecks(OpenstackEventChecksBase):
                                                            max_transitions))
             IssuesManager().add(NeutronL3HAWarning(msg))
 
-    def journalctl_args(self):
-        """ Args callback for event cli command """
-        args = []
-        kwargs = {'unit': 'neutron-l3-agent'}
-        if not HotSOSConfig.use_all_logs:
-            kwargs['date'] = self.cli.date(format="--iso-8601")
-
-        return args, kwargs
-
-    @EVENTCALLBACKS.callback(event_group='neutron.ml2-routers')
-    def vrrp_transitions(self, event):
+    def __call__(self, event):
         results = []
         for r in event.results:
-            router = self.ha_info.find_router_with_vr_id(r.get(3))
+            router = NeutronHAInfo().find_router_with_vr_id(r.get(3))
             if not router:
                 log.debug("could not find router with vr_id %s", r.get(3))
                 continue
@@ -318,11 +346,28 @@ class NeutronL3HAEventChecks(OpenstackEventChecksBase):
             # add info to summary
             return {'transitions': transitions}, 'keepalived'
 
-    def __summary_neutron_l3ha(self):
+
+class NeutronL3HAEventCheckJournalCtl(object):
+
+    def args(self):
+        """ Args callback for event cli command """
+        args = []
+        kwargs = {'unit': 'neutron-l3-agent'}
+        if not HotSOSConfig.use_all_logs:
+            kwargs['date'] = CLIHelper().date(format="--iso-8601")
+
+        return args, kwargs
+
+
+class NeutronL3HAEventChecks(OpenstackEventHandlerBase):
+    event_group = 'neutron.ml2-routers'
+
+    def __109_summary_neutron_l3ha(self):
         return self.final_event_results
 
 
 class AgentEventChecks(OpenstackChecksBase):
+    summary_part_index = 7
 
     def _run_checks(self, checks):
         # Only run if we think Openstack is installed.
@@ -332,9 +377,6 @@ class AgentEventChecks(OpenstackChecksBase):
         searcher = FileSearcher(constraint=SearchConstraintSearchSince(
                                         ts_matcher_cls=CommonTimestampMatcher))
         check_objs = [c(searcher=searcher) for c in checks]
-        for check in check_objs:
-            check.load()
-
         results = searcher.run()
         _final_results = {}
         for check in check_objs:
@@ -345,15 +387,13 @@ class AgentEventChecks(OpenstackChecksBase):
 
         return _final_results
 
-    @idx(1)
-    def __summary_api_info(self):
+    def __100_summary_api_info(self):
         checks = [APIEvents]
         results = self._run_checks(checks)
         if results:
             return results
 
-    @idx(2)
-    def __summary_agent_checks(self):
+    def __101_summary_agent_checks(self):
         checks = [AgentApparmorChecks,
                   ApacheEventChecks,
                   NeutronL3HAEventChecks,
