@@ -70,9 +70,9 @@ class AgentExceptionCheckResults(UserDict):
         if not exceptions:
             return
 
-        for exc_type in exceptions:
+        for exc_type, values in exceptions.items():
             exceptions_sorted = {}
-            for k, v in sorted(exceptions[exc_type].items(),
+            for k, v in sorted(values.items(),
                                key=lambda x: x[0]):
                 exceptions_sorted[k] = v
 
@@ -109,6 +109,7 @@ class AgentExceptionChecks(OpenstackChecksBase):
     importance. This class provides a way to identify exceptions in
     logs and provide a per-agent tally by date or time.
     """
+    summary_part_index = 6
 
     def __init__(self):
         super().__init__()
@@ -274,18 +275,7 @@ class AgentExceptionChecks(OpenstackChecksBase):
         self._agent_results = self._run(self.searchobj.run())
         return self._agent_results
 
-    def __summary_agent_warnings(self):
-        """
-        Only WARNING level exceptions
-        """
-        if self.agent_results and 'warning' in self.agent_results:
-            _exc_info = {}
-            for svc, results in self.agent_results['warning'].items():
-                _exc_info[svc] = dict(results)
-
-            return {agent: dict(info) for agent, info in _exc_info.items()}
-
-    def __summary_agent_exceptions(self):
+    def __200_summary_agent_exceptions(self):
         """
         Only ERROR level exceptions
         """
@@ -295,3 +285,14 @@ class AgentExceptionChecks(OpenstackChecksBase):
                 _exc_info[svc] = dict(results)
 
             return {agent: dict(info) for agent, info in _exc_info.items()}
+
+    def __201_summary_agent_warnings(self):
+        """
+        Only WARNING level exceptions
+        """
+        if self.agent_results and 'warning' in self.agent_results:
+            _exc_info = {}
+            for svc, results in self.agent_results['warning'].items():
+                _exc_info[svc] = dict(results)
+
+            return {agent: dict(info) for agent, info in _exc_info.items()}
